# Generated by Django 5.2 on 2025-05-01 12:00

import json
from django.db import migrations, models
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


def migrate_slides_to_streamfield(apps, schema_editor):
    EventPage = apps.get_model('core', 'EventPage')
    for page in EventPage.objects.all():
        slides = []
        
        # Check if slide1_img exists and add it to the slides list
        if page.slide1_img_id:
            slides.append({
                'type': 'slide',
                'value': {
                    'image': page.slide1_img_id,
                    'headline': page.slide1_headline,
                    'subline': page.slide1_subline,
                    'link_url': page.slide1_link_url,
                    'link_text': page.slide1_link_text,
                },
                'id': '1'
            })
        
        # Check if slide2_img exists and add it to the slides list
        if page.slide2_img_id:
            slides.append({
                'type': 'slide',
                'value': {
                    'image': page.slide2_img_id,
                    'headline': page.slide2_headline,
                    'subline': page.slide2_subline,
                    'link_url': page.slide2_link_url,
                    'link_text': page.slide2_link_text,
                },
                'id': '2'
            })
        
        # Check if slide3_img exists and add it to the slides list
        if page.slide3_img_id:
            slides.append({
                'type': 'slide',
                'value': {
                    'image': page.slide3_img_id,
                    'headline': page.slide3_headline,
                    'subline': page.slide3_subline,
                    'link_url': page.slide3_link_url,
                    'link_text': page.slide3_link_text,
                },
                'id': '3'
            })
        
        # Save the slides to the new StreamField
        if slides:
            page.slides = json.dumps(slides)
            page.save()


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0015_remove_eventpage_external_registration_code_and_more'),
    ]

    operations = [
        # Add the new slides StreamField
        migrations.AddField(
            model_name='eventpage',
            name='slides',
            field=wagtail.fields.StreamField([('slide', wagtail.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock()), ('headline', wagtail.blocks.CharBlock(max_length=512, required=False)), ('subline', wagtail.blocks.CharBlock(max_length=512, required=False)), ('link_url', wagtail.blocks.URLBlock(required=False)), ('link_text', wagtail.blocks.CharBlock(max_length=64, required=False))]))], blank=True, null=True, use_json_field=True),
        ),
        
        # Run the data migration
        migrations.RunPython(migrate_slides_to_streamfield),
        
        # Remove the old slide fields
        migrations.RemoveField(
            model_name='eventpage',
            name='slide1_img',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide1_headline',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide1_subline',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide1_link_url',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide1_link_text',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide2_img',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide2_headline',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide2_subline',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide2_link_url',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide2_link_text',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide3_img',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide3_headline',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide3_subline',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide3_link_url',
        ),
        migrations.RemoveField(
            model_name='eventpage',
            name='slide3_link_text',
        ),
    ]
