import datetime
from django import template
from django.db.models import Q
from wagtail.models import Site

register = template.Library()


@register.simple_tag(takes_context=True)
def get_site_root(context):
    return Site.find_for_request(context['request']).root_page


@register.simple_tag(takes_context=True)
def footer_about(context):
    return 'Individuelle Planung und Organisation von Seminaren, Meetings, Fortbildungsveranstaltungen und Events oder'\
        ' Teilbereichen davon.'


@register.inclusion_tag('core/tags/newsletter_minimal_form.html', takes_context=True)
def footer_newsletter(context):
    return {'request': context['request']}


@register.simple_tag
def get_upcoming_events(limit=3):
    """
    Returns a specified number of upcoming events ordered by start date.
    External events are excluded from the results.
    Usage: {% get_upcoming_events 3 as upcoming_events %}
    """
    from core.models import EventPage
    return EventPage.objects.live().filter(
        show_in_event_calendar=True,
        is_external=False,
    ).filter(
        Q(end_date__gte=datetime.datetime.now()) | Q(end_date__isnull=True, start_date__gte=datetime.datetime.now())
    ).order_by('start_date')[:limit]


@register.inclusion_tag('core/tags/event_calendar.html', takes_context=True)
def event_calendar(context):
    from core.models import EventPage
    return {
        'request': context['request'],
        'events': EventPage.objects.live().filter(
            show_in_event_calendar=True,
        ).filter(
            Q(end_date__gte=datetime.datetime.now()) | Q(end_date__isnull=True, start_date__gte=datetime.datetime.now())
        ).order_by('start_date'),
    }
